@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 
 # This cannot be executed from within a Ruby-based environment (like Rake)
 # since Bundler will affect the subshell environments.
@@ -10,30 +10,33 @@ function header() {
 }
 
 function green() {
-  echo $(tput setaf 2)$@$(tput sgr0)
+  echo "$(tput setaf 2)$*$(tput sgr0)"
 }
 
 function update() {
+  bundle config --local path .bundle
   bundle update | grep -ve "^Using "
 }
 
 function install() {
-  bundle install --quiet && green "  OK"
+  bundle install --quiet --path=.bundle && green "  OK"
 }
 
-root=$(dirname $0)
+root=$(dirname "$0")
 
-# Set by Travis CI; interferes with the nested repos
+# Previously needed by Travis CI; might still be needed at Github Actions
+# due to nested repos
 unset BUNDLE_GEMFILE
 
 if [[ $1 == "install" ]]; then
   header "Installing gem dependencies"
   install
 
-  for app_path in $root/spec/railsapps/rails_*; do
+  for app_path in "$root"/spec/railsapps/rails_*; do
     (
-      cd $app_path
-      header "Installing gems for $(basename $app_path)"
+      header "Rails app $(basename "$app_path")"
+      cd "$app_path"
+      echo -n "Installing gems for $(basename "$app_path")"
       install
     )
   done
@@ -43,10 +46,10 @@ elif [[ $1 == "update" ]]; then
   header "Updating gem dependencies"
   update
 
-  for app_path in $root/spec/railsapps/rails_*; do
+  for app_path in "$root"/spec/railsapps/rails_*; do
     (
-      cd $app_path
-      header "Updating $(basename $app_path)"
+      cd "$app_path"
+      header "Updating $(basename "$app_path")"
       update
     )
   done
